﻿* Encoding: UTF-8.
* Study 1 - Data analysis
* Goswami and Urminsky "When should the ask be a nudge?" 
* Journal of Marketing Research 2016

* VARIABLE DEFINITIONS.
* ID#: respondentent ID.
* Hits: points in ball-rolling game.
* RewardInd: 1 if won extra $1, 0 otherswise.
* G_Male1: 1 if male, 2 if female
* Age: age in years
* Ethnicity: text of self-reported ethnicity
* Mood measures, on 1 -7 scale.
*       Happy_7: 1= unhappy, 7=happy
*       Pleased_7: 1=annoyed, 7=pleased
*       GoodMood_7: 1=bad mood, 7=good mood
*       AvgMood: average of three measures
* r1-r11: items on Hong and Faeda (1996) Reactance scale, rated on 1-5 scale (from Strongly Disagree to Strongly Agree)
* Reactance: Average of 11 items on Hong and Faeda (1996) Reactance scale
* NOTE: Some participants did not complete the reactance scale.
* ReactanceCatg: 1 if high reactance, 0 if low
* Default: Randomly assigned default condition (0=no default, .50 = 50 cent default, 3= 3 dollar default)
* Donated: 1=donated, 0 = not
* Donation: Amount donated in dollars (0= no donation)


* VARIABLE PREPARATION.

* amount donated among those who donated.
compute conddonation=99.
if (donationind eq 1) conddonation=donation.
missing values conddonation (99).

* was a default present (1=yes). 
compute defpresent=0.
if (default ne 0) defpresent=1.

* interactions.
compute int_defamt_reward=default*rewardInd.
compute int_defpres_reward=defpresent*rewardInd.
compute int_defamt_mood=default*Avgmood.
compute int_defpres_mood=defpresent*Avgmood.
compute int_defpres_react=defpresent*Reactance.
compute int_defamt_react=default*Reactance.
execute.

* gave specific amounts.
compute gave50c=0.
compute gave3d=0.
if (donation eq 0.5) gave50c=1.
if (donation eq 3) gave3d=1.
execute.


* DESCRIPTIVE STATISTICS.
* Used for Figure 2.
* Revenue Per Person is based on 'Donation'.
* Donation Rate is based on 'Donated'.
* revenue per person is based on 'conddonation'.
SORT CASES  BY Default.
SPLIT FILE LAYERED BY Default.

DESCRIPTIVES VARIABLES=Donated Donation conddonation
  /STATISTICS=MEAN STDDEV MIN MAX SEMEAN.

SPLIT FILE OFF.

T-TEST GROUPS=Default(.5 3)
  /MISSING=ANALYSIS
  /VARIABLES=Donated Donation conddonation
  /CRITERIA=CI(.95).

* Test for basic default effect.
* 50 cents as default.
USE ALL.
COMPUTE filter_$=(default < 3).
FILTER BY filter_$.
EXECUTE.
CROSSTABS  /TABLES=gave50c BY Default  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ   /CELLS=COUNT COLUMN   /COUNT ROUND CELL.

* 3 dollars as default.
USE ALL.
COMPUTE filter_$=(Default eq 0 | default > 1).
FILTER BY filter_$.
EXECUTE.

CROSSTABS  /TABLES=gave3d BY Default  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ   /CELLS=COUNT COLUMN   /COUNT ROUND CELL.


* Effect of default on revenue per person.
FILTER OFF.
USE ALL.
EXECUTE.
UNIANOVA Donation BY Default  /METHOD=SSTYPE(3)  /INTERCEPT=INCLUDE  /CRITERIA=ALPHA(0.05)
  /DESIGN=Default.

* Distribution of choices by condition - all.
CROSSTABS  /TABLES=Donation BY Default
  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ    /CELLS=COUNT COLUMN   /COUNT ROUND CELL.

* Distribution of choices by condition - low vs. high.
USE ALL.
COMPUTE filter_$=(default >0).
FILTER BY filter_$.
EXECUTE.
CROSSTABS  /TABLES=Donation BY Default
  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ    /CELLS=COUNT COLUMN   /COUNT ROUND CELL.
FILTER OFF.
USE ALL.
EXECUTE.


* LOWER BAR EFFECT.
* Donation rate - low vs. high.
USE ALL.
COMPUTE filter_$=(default >0).
FILTER BY filter_$.
EXECUTE.
CROSSTABS  /TABLES=Donated BY Default
  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ    /CELLS=COUNT COLUMN   /COUNT ROUND CELL.
FILTER OFF.
USE ALL.
EXECUTE.

* SCALE BACK EFFECT.
T-TEST GROUPS=Default(.5 3)
  /MISSING=ANALYSIS
  /VARIABLES=conddonation
  /CRITERIA=CI(.95).

* TEST MODERATION BY REACTANCE
USE ALL.

* reactance by default presence.
*Table A1.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER defpresent Reactance int_defpres_react.

*Table A2.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER defpresent Reactance int_defpres_react.

*Table A3.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER defpresent Reactance int_defpres_react.

LOGISTIC REGRESSION VARIABLES Donated
  /METHOD=ENTER Reactance defpresent defpresent*Reactance 
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20) CUT(.5).

* reactance by default amount.
*Table A4.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER defpresent Default int_defamt_react Reactance .

*Table A5.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER defpresent Default int_defamt_react Reactance .

*Table A6.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER defpresent Default int_defamt_react Reactance .

LOGISTIC REGRESSION VARIABLES Donated
  /METHOD=ENTER defpresent Default Default*Reactance Reactance 
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20) CUT(.5).





