﻿* Encoding: windows-1252.
* Study 2 - Data analysis
* Goswami and Urminsky "When should the ask be a nudge?" 
* Journal of Marketing Research 2016

* KEY VARIABLE DEFINITIONS.
* Default: Randomly assigned default condition (0=no default, other amounts indicate that amount was the default)
* Defpresent: 1 if an option is defaulted, 0 otherwise
* Donated: 1=donated, 0 = not
* Donation: Amount donated in dollars (0= no donation).
* Conddonation: Amount donated by donors (missing = no donation) 
* All other variables are defined in the Excel file 'Data Dictionary Study 2'.

* VARIABLE PREPARATION.

* study specific dummy codes.
compute Study2a=0.
compute Study2b=0.
compute Study2c=0.
compute Study2d=0.
compute Study2e=0.
compute Study2f=0.
if (Study_Num eq 1) Study2a=1.
if (Study_Num eq 2) Study2b=1.
if (Study_Num eq 3) Study2c=1.
if (Study_Num eq 4) Study2d=1.
if (Study_Num eq 5) Study2e=1.
if (Study_Num eq 6) Study2f=1.
execute.

compute defaultsq=default*default.
compute agesq=age*age.
execute.

* code variables.

compute gendernum=0.
if (gender eq "F") gendernum=1.
if (gender eq "M") gendernum=2.
compute controlcond=1-defpresent.
compute lntime=ln(Time+1).
compute orgposcharityidx=(orgFit+orgFavorable+orgTrust)/3.
compute org_involve=orgVolWith+orgDonatedTo+orgBenfFrom.
compute orgNetFave=(OrgFavorable+orgTrust+orgFit)/3.
compute splitOrgDonation=0.
if (orgDonation gt 52) splitOrgDonation=1.
compute defgood=(TrustSrc+Guidance+Useful)/3.
compute defbad=(HvyHanded +DetCh)/2.
compute def_frame=frsuggest-frrandom.
compute CharityAttitude=(Trust+Favorable+Fit)/3.
execute.


* interactions with default presence.
compute int_dpresent_react=defpresent*react.
compute int_dpresent_inc=defpresent*inc.
compute int_dpresent_saving=defpresent*saving.
compute int_dpresent_age=defpresent*age.
compute int_dpresent_agesq=defpresent*agesq.
compute int_dpresent_gender=defpresent*gendernum.
compute int_dpresent_freq=defpresent*freq.
compute int_dpresent_numopt=defpresent*NumOfOpts.
compute int_dpresent_framing=defpresent*def_frame.
compute int_dpresent_orgNetFave=defpresent*orgNetFave.
compute int_dpresent_orgDonation=defpresent*orgDonation.
compute int_dpresent_org_involve=defpresent*org_involve.
compute int_dpresent_orgKnown=defpresent*orgKnown.
compute int_dpresent_navigator=defpresent*navigator.
compute int_dpresent_textpos=defpresent*textpos.


* interactions with default size.
compute int_default_react=default*react.
compute int_default_inc=default*inc.
compute int_default_saving=default*saving.
compute int_default_age=default*age.
compute int_default_agesq=default*agesq.
compute int_default_gender=default*gendernum.
compute int_default_freq=default*freq.
compute int_default_order=default*deforder.
compute int_default_numopt=default*NumOfOpts.
compute int_default_framing=default*def_frame.
compute int_default_orgNetFave=default*orgNetFave.
compute int_default_orgDonation=default*orgDonation.
compute int_default_org_involve=default*org_involve.
compute int_default_orgKnown=default*orgKnown.
compute int_default_navigator=default*navigator.
compute int_default_textpos=default*textpos.
execute.



*-##############################################.
* PART 1: COMBINED TESTS FOR BODY OF PAPER.
*-##############################################.


*--------------------------------------------------------------------------.
* TEST FOR HETEROGENEITY ACROSS STUDIES.

FILTER OFF.
USE ALL.
USE ALL.
COMPUTE filter_$=(Default=0).
FILTER BY filter_$.
EXECUTE.

UNIANOVA Donation BY Study_Num
  /METHOD=SSTYPE(3)  /INTERCEPT=INCLUDE  /CRITERIA=ALPHA(0.05)  /DESIGN=Study_Num.

UNIANOVA Donated BY Study_Num
  /METHOD=SSTYPE(3)  /INTERCEPT=INCLUDE  /CRITERIA=ALPHA(0.05)  /DESIGN=Study_Num.

UNIANOVA conddonation BY Study_Num
  /METHOD=SSTYPE(3)  /INTERCEPT=INCLUDE  /CRITERIA=ALPHA(0.05)  /DESIGN=Study_Num.

FILTER OFF.
USE ALL.

*--------------------------------------------------------------------------.
* CHOICE OF DEFAULTED OPTION.
* See Study2_DefaultChoice Excel file.


SORT CASES  BY Study_Num Manip2.
SPLIT FILE LAYERED BY Study_Num Manip2.
CROSSTABS
  /TABLES=Donation BY default
  /FORMAT=AVALUE TABLES
  /CELLS=COUNT 
  /COUNT ROUND CELL.

SPLIT FILE OFF.

*--------------------------------------------------------------------------.
* EFFECT OF DEFAULT PRESENCE.

* revenue (Table A7).
T-TEST GROUPS=defPresent(0 1)  /MISSING=ANALYSIS  /VARIABLES=Donation  /CRITERIA=CI(.95).

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER defPresent Study2b Study2c Study2d Study2e Study2f.

* donation rate (Table A8).
T-TEST GROUPS=defPresent(0 1)  /MISSING=ANALYSIS  /VARIABLES=Donated  /CRITERIA=CI(.95).

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER defPresent Study2b Study2c Study2d Study2e Study2f.

LOGISTIC REGRESSION VARIABLES Donated
  /METHOD=ENTER defPresent Study2b Study2c Study2d Study2e Study2f 
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20) CUT(.5).

* average donation (Table A9).
T-TEST GROUPS=defPresent(0 1)  /MISSING=ANALYSIS  /VARIABLES=CondDonation  /CRITERIA=CI(.95).

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER defPresent Study2b Study2c Study2d Study2e Study2f.


*--------------------------------------------------------------------------.
* SIZE OF DEFAULT.

*revenue (Table A10).
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER controlcond default Study2b Study2c Study2d Study2e Study2f.

*donation rate (Table A11).
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER controlcond default Study2b Study2c Study2d Study2e Study2f.

LOGISTIC REGRESSION VARIABLES Donated
  /METHOD=ENTER controlcond default Study2b Study2c Study2d Study2e Study2f 
  /CRITERIA=PIN(.05) POUT(.10) ITERATE(20) CUT(.5).

*average donation (Table A12).
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER controlcond default Study2b Study2c Study2d Study2e Study2f.


*--------------------------------------------------------------------------.
* TESTS FOR NONLINEAR EFFECT OF DEFAULT SIZE.

* 1. Quadratic effects.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER controlcond default defaultsq Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER controlcond default defaultsq Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER controlcond default defaultsq Study2b Study2c Study2d Study2e Study2f.

* 2. rerun without fixed effects.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER controlcond default .

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER controlcond default defaultsq .

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER controlcond default .

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER controlcond default defaultsq .

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER controlcond default .

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER controlcond default defaultsq .

* 3. spline models.
* revenue.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER controlcond default Study2b Study2c Study2d Study2e Study2f.

MODEL PROGRAM ba0=4.3 ba1=.03 bb1=.03 knot1=8 cc=.45 sb=-.64 sc=-.53 sd=.84 se=-.33 sf=-1.3 .
COMPUTE pc1 = (default LT knot1).
COMPUTE pc2 = (default GE knot1).
COMPUTE predex1 = ba0 + ba1*default*pc1 + bb1*(default-knot1)*pc2 + cc*controlcond+sb*Study2b +sc*Study2c +sd*Study2d +se*Study2e +sf*Study2f.
CNLR Donation / PRED = predex1 /SAVE pred resid (residex1).
GRAPH
/SCATTERPLOT(BIVAR)= predex1 WITH residex1 .
GRAPH
/SCATTERPLOT(OVERLAY)=default default WITH Donation predex1 (PAIR) .

* donation rate.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER controlcond default Study2b Study2c Study2d Study2e Study2f.

MODEL PROGRAM ba0=.6 ba1=-.005 bb1=-.005 knot1=8 cc=-.035 sb=-.07 sc=.01 sd=.23 se=.17 sf=-.01 .
COMPUTE pc1 = (default LT knot1).
COMPUTE pc2 = (default GE knot1).
COMPUTE predex2 = ba0 + ba1*default*pc1 + bb1*(default-knot1)*pc2 + cc*controlcond+sb*Study2b +sc*Study2c +sd*Study2d +se*Study2e +sf*Study2f.
CNLR Donated / PRED = predex2 /SAVE pred resid (residex2).
GRAPH
/SCATTERPLOT(BIVAR)= predex2 WITH residex2 .
GRAPH
/SCATTERPLOT(OVERLAY)=default default WITH Donated predex2 (PAIR) .

* average donation.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER controlcond default Study2b Study2c Study2d Study2e Study2f.

MODEL PROGRAM ba0=7.4 ba1=.1 bb1=.1 knot1=8 cc=1.13 sb=-.04 sc=-1.05 sd=-1.35 se=-2.37 sf=-2.18 .
COMPUTE pc1 = (default LT knot1).
COMPUTE pc2 = (default GE knot1).
COMPUTE predex3 = ba0 + ba1*default*pc1 + bb1*(default-knot1)*pc2 + cc*controlcond+sb*Study2b +sc*Study2c +sd*Study2d +se*Study2e +sf*Study2f.
CNLR CondDonation / PRED = predex3 /SAVE pred resid (residex3).
GRAPH
/SCATTERPLOT(BIVAR)= predex3 WITH residex3 .
GRAPH
/SCATTERPLOT(OVERLAY)=default default WITH CondDonation predex3 (PAIR) .


*-----------------------------------------------------------------------------------------------------------------------.
* DONOR CHARACTERISTICS.


* direct effects of donor characteristics, including reactance (Tables A13-A15) and income (Tables A16-A18).
* revenue .
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER   react  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER   inc  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER   saving  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER   age  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER   age agesq Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER   gendernum  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER   freq  Study2b Study2c Study2d Study2e Study2f.



* donation rate .
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER   react  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER   inc  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER   saving  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER   age  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  age agesq Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER   gendernum  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER   freq  Study2b Study2c Study2d Study2e Study2f.

* average donation .
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER   react  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER   inc  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER   saving  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER   age  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER   age agesq Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER   gendernum  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER   freq  Study2b Study2c Study2d Study2e Study2f.


* testing whether reactance moderates effect of default presence (Tables A19-A21).
* testing whether income moderates effect of default presence (Tables A22-A24).
* also testing savings, age, quadratic age, gender and donation frequency.

* revenue - default presence.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  defpresent int_dpresent_react react  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  defpresent int_dpresent_inc inc  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  defpresent int_dpresent_saving saving  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  defpresent int_dpresent_age age  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  defpresent int_dpresent_age int_dpresent_agesq age agesq Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  defpresent int_dpresent_gender gendernum  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  defpresent int_dpresent_freq freq  Study2b Study2c Study2d Study2e Study2f.



* donation rate - default presence.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  defpresent int_dpresent_react react  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  defpresent int_dpresent_inc inc  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  defpresent int_dpresent_saving saving  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  defpresent int_dpresent_age age  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  defpresent int_dpresent_age int_dpresent_agesq age agesq Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  defpresent int_dpresent_gender gendernum  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  defpresent int_dpresent_freq freq  Study2b Study2c Study2d Study2e Study2f.

* average donation - default presence.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  defpresent int_dpresent_react react  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  defpresent int_dpresent_inc inc  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  defpresent int_dpresent_saving saving  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  defpresent int_dpresent_age age  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  defpresent int_dpresent_age int_dpresent_agesq age agesq Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  defpresent int_dpresent_gender gendernum  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  defpresent int_dpresent_freq freq  Study2b Study2c Study2d Study2e Study2f.


* testing whether reactance moderates effect of default size (Tables A25-A27).
* testing whether income moderates effect of default size (Tables A28-A30).
* also testing savings, age, quadratic age, gender and donation frequency.

* revenue -- default size.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  controlcond default int_default_react react  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  controlcond default int_default_inc inc  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  controlcond default int_default_saving saving  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  controlcond default int_default_age age  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  controlcond default int_default_age int_dpresent_agesq age agesq Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  controlcond default int_default_gender gendernum  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  controlcond default int_default_freq freq  Study2b Study2c Study2d Study2e Study2f.


* donation rate -- default size.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  controlcond default int_default_react react  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  controlcond default int_default_inc inc  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  controlcond default int_default_saving saving  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  controlcond default int_default_age age  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  controlcond default int_default_age int_dpresent_agesq age agesq Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  controlcond default int_default_gender gendernum  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  controlcond default int_default_freq freq  Study2b Study2c Study2d Study2e Study2f.

* average donation -- default size.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  controlcond default int_default_react react  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  controlcond default int_default_inc inc  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  controlcond default int_default_saving saving  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  controlcond default int_default_age age  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  controlcond default int_default_age int_dpresent_agesq age agesq Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  controlcond default int_default_gender gendernum  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  controlcond default int_default_freq freq  Study2b Study2c Study2d Study2e Study2f.

* 
*--------------------------------------------------------------------------.
* DEFAULT MENU POSITION.
* NOTE: EXCLUDE STUDY2c Manip2=0 (free choice condition) FOR ALL MENU EFFECTS.

USE ALL.
COMPUTE filter_$=(Study_Num<>3 | Manip2>0).
FILTER BY filter_$.
EXECUTE.

*default size controlling for default order (Tables A31 to A33).
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER controlcond default deforder Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER controlcond default deforder Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER controlcond default deforder Study2b Study2c Study2d Study2e Study2f.

*interaction of default size and default order (Tables A34 to A36).
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER controlcond default deforder int_default_order Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER controlcond default deforder int_default_order Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER controlcond default deforder int_default_order Study2b Study2c Study2d Study2e Study2f.

USE ALL.
COMPUTE filter_$=(Study_Num eq 1 | Study_Num eq 2 | Study_Num eq 5).
FILTER BY filter_$.
EXECUTE.
* effects of menu characteristics on default size effect (Tables A37-A39).
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER controlcond default  NumOfOpts int_default_numopt Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER controlcond default  NumOfOpts int_default_numopt Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER controlcond default  NumOfOpts int_default_numopt Study2b Study2c Study2d Study2e Study2f.

USE ALL.
EXECUTE.

* 
*-----------------------------------------------------------------------------------------------------------.
* INFORMATION AND FRAMING.

* FRAMING ----------------------------------------.
* This was tested in Studies 2a, 2b, 2d and 2e.
* moderation of default presence.

* suggested framing & control only (Tables A40-A42).
USE ALL.
COMPUTE filter_$=((Study_Num eq 1 | Study_Num eq 2 | Study_Num eq 4 | Study_Num eq 5) & def_frame> -1).
FILTER BY filter_$.
EXECUTE.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER defPresent  Study2b Study2d Study2e.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER controlcond default Study2b Study2d Study2e.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER controlcond default Study2b Study2d Study2e.


* random framing & control only (Tables A43-A45).
USE ALL.
COMPUTE filter_$=((Study_Num eq 1 | Study_Num eq 2 | Study_Num eq 4 | Study_Num eq 5) & def_frame<1).
FILTER BY filter_$.
EXECUTE.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER defPresent  Study2b Study2d Study2e .

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER controlcond default Study2b Study2d Study2e .

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER controlcond default Study2b Study2d Study2e .

*interaction of default framing and default presence (Tables A46-A48).
USE ALL.
COMPUTE filter_$=(Study_Num eq 1 | Study_Num eq 2 | Study_Num eq 4 | Study_Num eq 5).
FILTER BY filter_$.
EXECUTE.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER defPresent def_frame  int_dpresent_framing Study2b Study2d Study2e.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER defPresent def_frame int_dpresent_framing Study2b Study2d Study2e.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER defPresent def_frame int_dpresent_framing Study2b Study2d Study2e.

* interaction of default framing and default size (Tables A49-A51).

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER controlcond default def_frame int_default_framing Study2b Study2d Study2e.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER controlcond default def_frame int_default_framing Study2b Study2d Study2e.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER controlcond default def_frame int_default_framing Study2b Study2d Study2e.

USE ALL.
EXECUTE.

* 
*----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------.
* DEFAULT PRESENT AND CHARITY TYPE.
* orgNetFave is organization favorability (Tables A52, A54, A56).
* orgDonation is organization appeal (Tables A53, A55, A57).
* we also analyzed organization involvement and knowledge.

* revenue per person.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  defpresent orgNetFave  int_dpresent_orgNetFave Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  defpresent orgDonation  int_dpresent_orgDonation Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  defpresent org_involve  int_dpresent_org_involve Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  defpresent orgKnown  int_dpresent_orgKnown Study2b Study2c Study2d Study2e Study2f.

*donation rate.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  defpresent orgNetFave  int_dpresent_orgNetFave Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  defpresent orgDonation  int_dpresent_orgDonation Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  defpresent org_involve  int_dpresent_org_involve Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  defpresent orgKnown  int_dpresent_orgKnown Study2b Study2c Study2d Study2e Study2f.

* average donation.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  defpresent orgNetFave  int_dpresent_orgNetFave Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  defpresent orgDonation  int_dpresent_orgDonation Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  defpresent org_involve  int_dpresent_org_involve Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  defpresent orgKnown  int_dpresent_orgKnown Study2b Study2c Study2d Study2e Study2f.

* 
* DEFAULT SIZE AND CHARITY TYPE.

* revenue per person.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  controlcond default orgNetFave  int_default_orgNetFave Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  controlcond default orgDonation  int_default_orgDonation Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  controlcond default org_involve  int_default_org_involve Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER  controlcond default orgKnown  int_default_orgKnown Study2b Study2c Study2d Study2e Study2f.


* donation rate.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  controlcond default orgNetFave  int_default_orgNetFave Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  controlcond default orgDonation  int_default_orgDonation Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  controlcond default org_involve  int_default_org_involve Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER  controlcond default orgKnown  int_default_orgKnown Study2b Study2c Study2d Study2e Study2f.

* average donation.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  controlcond default orgNetFave  int_default_orgNetFave Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  controlcond default orgDonation  int_default_orgDonation Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  controlcond default org_involve  int_default_org_involve Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER  controlcond default orgKnown  int_default_orgKnown Study2b Study2c Study2d Study2e Study2f.


* 
* COMPARING LOW AND HIGH POPULARITY CHARITIES.

* low popularity.
USE ALL.
COMPUTE filter_$=(splitOrgDonation=0).
FILTER BY filter_$.
EXECUTE.

T-TEST GROUPS=defPresent(0 1)
  /MISSING=ANALYSIS
  /VARIABLES=Donation Donated CondDonation
  /CRITERIA=CI(.95).

CROSSTABS
  /TABLES=Donated BY defPresent
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT COLUMN 
  /COUNT ROUND CELL.

* high popularity.
USE ALL.
COMPUTE filter_$=(splitOrgDonation=1).
FILTER BY filter_$.
EXECUTE.

T-TEST GROUPS=defPresent(0 1)
  /MISSING=ANALYSIS
  /VARIABLES=Donation Donated CondDonation
  /CRITERIA=CI(.95).

CROSSTABS
  /TABLES=Donated BY defPresent
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT COLUMN 
  /COUNT ROUND CELL.

USE ALL.
EXECUTE.

* INFORMATION ----------------------------------------.

* Inclusion of Charity Navigator information.

* moderation of default effect (Tables A58-A60).
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER defPresent  navigator int_dpresent_navigator Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER defPresent  navigator int_dpresent_navigator Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER defPresent  navigator  int_dpresent_navigator Study2b Study2c Study2d Study2e Study2f.

* moderation of default size.
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER defPresent  default navigator int_default_navigator Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER defPresent  default navigator int_default_navigator  Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER defPresent  default navigator int_default_navigator  Study2b Study2c Study2d Study2e Study2f.


* INFORMATION VALENCE.

* effect of positive info on default effect (Tables A61-A63).
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER defPresent textpos int_dpresent_textpos Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER defPresent textpos int_dpresent_textpos Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER defPresent textpos int_dpresent_textpos Study2b Study2c Study2d Study2e Study2f.

* interaction of positive info and default size .
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER controlcond default textpos int_default_textpos Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER controlcond default  textpos int_default_textpos Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER controlcond default  textpos int_default_textpos Study2b Study2c Study2d Study2e Study2f.

* 
*-------------------------------------------------------------------------------------------------------------------.
* TEST OF MANIPULATED INFORMATION IN STUDY 2A.

USE ALL.
COMPUTE filter_$=(Study_Num=1).
FILTER BY filter_$.
EXECUTE.

* INFORMATION VALENCE -- STUDY 2A ONLY.

* effect of positive info on default effect (Tables A62-A64).
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER defPresent textpos int_dpresent_textpos Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER defPresent textpos int_dpresent_textpos Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER defPresent textpos int_dpresent_textpos Study2b Study2c Study2d Study2e Study2f.

* interaction of positive info and default size (Tables A65-A67).
REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donation  /METHOD=ENTER controlcond default textpos int_default_textpos Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT Donated  /METHOD=ENTER controlcond default  textpos int_default_textpos Study2b Study2c Study2d Study2e Study2f.

REGRESSION  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CondDonation  /METHOD=ENTER controlcond default  textpos int_default_textpos Study2b Study2c Study2d Study2e Study2f.


* effect of info when there is no default.
USE ALL.
COMPUTE filter_$=(Study_Num=1 & defpresent eq 0).
FILTER BY filter_$.
EXECUTE.

T-TEST GROUPS=textpos(0 1)
  /MISSING=ANALYSIS
  /VARIABLES=Donation CondDonation
  /CRITERIA=CI(.95).

CROSSTABS
  /TABLES=Donated BY textpos
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT COLUMN 
  /COUNT ROUND CELL.

* effect of info when there is a default.
USE ALL.
COMPUTE filter_$=(Study_Num=1 & defpresent eq 1).
FILTER BY filter_$.
EXECUTE.

T-TEST GROUPS=textpos(0 1)
  /MISSING=ANALYSIS
  /VARIABLES=Donation CondDonation
  /CRITERIA=CI(.95).

CROSSTABS
  /TABLES=Donated BY textpos
  /FORMAT=AVALUE TABLES
  /STATISTICS=CHISQ 
  /CELLS=COUNT COLUMN 
  /COUNT ROUND CELL.

USE ALL.
EXECUTE.

*-------------------------------------------------------------------------------------------------------------------.
* ATTITUDES TOWARDS DEFAULTS.

USE ALL.
COMPUTE filter_$=(defpresent eq 1).
FILTER BY filter_$.
EXECUTE.

* attitudes towards defaults (Tables A68-A69).
REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT defbad  /METHOD=ENTER default Study2b Study2c Study2d Study2e Study2f orgposcharityidx.

REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT defgood  /METHOD=ENTER default Study2b Study2c Study2d Study2e Study2f orgposcharityidx.

* mediation by attitudes towards defaults (Tables A70-A75).
REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT donation  /METHOD=ENTER default Study2b Study2c Study2d Study2e Study2f orgposcharityidx.

REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT donation  /METHOD=ENTER default defgood defbad Study2b Study2c Study2d Study2e Study2f orgposcharityidx.

REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT donated  /METHOD=ENTER default Study2b Study2c Study2d Study2e Study2f orgposcharityidx.

REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT donated  /METHOD=ENTER default defgood defbad Study2b Study2c Study2d Study2e Study2f orgposcharityidx.

REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT conddonation  /METHOD=ENTER default Study2b Study2c Study2d Study2e Study2f orgposcharityidx.

REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT conddonation  /METHOD=ENTER default defgood defbad Study2b Study2c Study2d Study2e Study2f orgposcharityidx.
* ^^ 
*-------------------------------------------------------------------------------------------------------------------.
* ATTITUDES TOWARDS CHARITIES AND DONATION.

USE ALL.
EXECUTE.

* Effect of default size on attitudes (Tables A76-A77).
REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CharityAttitude  /METHOD=ENTER defpresent Study2b Study2c Study2d Study2e Study2f orgposcharityidx.

REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT DonationAttitude  /METHOD=ENTER defpresent Study2b Study2c Study2d Study2e Study2f.



USE ALL.
COMPUTE filter_$=(defpresent eq 1).
FILTER BY filter_$.
EXECUTE.

* Effect of default size on attitudes (Tables A78-A79).
REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT CharityAttitude  /METHOD=ENTER default Study2b Study2c Study2d Study2e Study2f orgposcharityidx.

REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT DonationAttitude  /METHOD=ENTER default Study2b Study2c Study2d Study2e Study2f .


USE ALL.
EXECUTE.
*-------------------------------------------------------------------------------------------------------------------.
* DEFAULT DISTRACTION.

REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT lntime  /METHOD=ENTER defpresent Study2b Study2c Study2d Study2e Study2f.

CORRELATIONS  /VARIABLES=defPresent lntime  /PRINT=TWOTAIL NOSIG  /MISSING=PAIRWISE.

* Effect of default presence and number of options on donation rate (Table 80).
REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT donated  /METHOD=ENTER defpresent numofopts int_dpresent_numopt Study2b Study2c Study2d Study2e Study2f.

* effect of info when there is no default.
USE ALL.
COMPUTE filter_$=(defpresent eq 0).
FILTER BY filter_$.
EXECUTE.

REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT donated  /METHOD=ENTER numofopts Study2b Study2c Study2d Study2e Study2f.

CORRELATIONS  /VARIABLES=donated numofopts  /PRINT=TWOTAIL NOSIG  /MISSING=PAIRWISE.

* effect of info when there is a default.
USE ALL.
COMPUTE filter_$=(defpresent eq 1).
FILTER BY filter_$.
EXECUTE.

REGRESSION
  /MISSING LISTWISE  /STATISTICS COEFF OUTS R ANOVA  /CRITERIA=PIN(.05) POUT(.10)  /NOORIGIN 
  /DEPENDENT donated  /METHOD=ENTER numofopts Study2b Study2c Study2d Study2e Study2f.

CORRELATIONS  /VARIABLES=donated numofopts  /PRINT=TWOTAIL NOSIG  /MISSING=PAIRWISE.

USE ALL.
EXECUTE.
*-------------------------------------------------------------------------------------------------------------------.

*-####################################################.
* PART 2: TESTS FOR INDIVIDUAL STUDIES -- APPENDIX B.
*-####################################################.

USE ALL.
EXECUTE.

SORT CASES  BY Study_Num.
SPLIT FILE LAYERED BY Study_Num.

* Table B1.
CROSSTABS  /TABLES=Donated BY defPresent
  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ   /CELLS=COLUMN   /COUNT ROUND CELL.

T-TEST GROUPS=defPresent(0 1)  /MISSING=ANALYSIS
  /VARIABLES=Donation CondDonation  /CRITERIA=CI(.95).



* Table B2.
USE ALL.
COMPUTE filter_$=(defpresent eq 0).
FILTER BY filter_$.
EXECUTE.

DESCRIPTIVES VARIABLES=Donation Donated CondDonation
  /STATISTICS=MEAN STDDEV MIN MAX.

USE ALL.
COMPUTE filter_$=(default eq 0 | default eq .25).
FILTER BY filter_$.
EXECUTE.

CROSSTABS  /TABLES=Donated BY defPresent
  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ   /CELLS=COLUMN   /COUNT ROUND CELL.

T-TEST GROUPS=defPresent(0 1)  /MISSING=ANALYSIS
  /VARIABLES=Donation CondDonation  /CRITERIA=CI(.95).

USE ALL.
COMPUTE filter_$=(default eq 0 | default eq .5).
FILTER BY filter_$.
EXECUTE.

CROSSTABS  /TABLES=Donated BY defPresent
  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ   /CELLS=COLUMN   /COUNT ROUND CELL.

T-TEST GROUPS=defPresent(0 1)  /MISSING=ANALYSIS
  /VARIABLES=Donation CondDonation  /CRITERIA=CI(.95).

USE ALL.
COMPUTE filter_$=(default eq 0 | default eq 1).
FILTER BY filter_$.
EXECUTE.

CROSSTABS  /TABLES=Donated BY defPresent
  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ   /CELLS=COLUMN   /COUNT ROUND CELL.

T-TEST GROUPS=defPresent(0 1)  /MISSING=ANALYSIS
  /VARIABLES=Donation CondDonation  /CRITERIA=CI(.95).

USE ALL.
COMPUTE filter_$=(default eq 0 | default eq 2).
FILTER BY filter_$.
EXECUTE.

CROSSTABS  /TABLES=Donated BY defPresent
  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ   /CELLS=COLUMN   /COUNT ROUND CELL.

T-TEST GROUPS=defPresent(0 1)  /MISSING=ANALYSIS
  /VARIABLES=Donation CondDonation  /CRITERIA=CI(.95).

USE ALL.
COMPUTE filter_$=(default eq 0 | default eq 3).
FILTER BY filter_$.
EXECUTE.

CROSSTABS  /TABLES=Donated BY defPresent
  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ   /CELLS=COLUMN   /COUNT ROUND CELL.

T-TEST GROUPS=defPresent(0 1)  /MISSING=ANALYSIS
  /VARIABLES=Donation CondDonation  /CRITERIA=CI(.95).

USE ALL.
COMPUTE filter_$=(default eq 0 | default eq 5).
FILTER BY filter_$.
EXECUTE.

CROSSTABS  /TABLES=Donated BY defPresent
  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ   /CELLS=COLUMN   /COUNT ROUND CELL.

T-TEST GROUPS=defPresent(0 1)  /MISSING=ANALYSIS
  /VARIABLES=Donation CondDonation  /CRITERIA=CI(.95).

USE ALL.
COMPUTE filter_$=(default eq 0 | default eq 10).
FILTER BY filter_$.
EXECUTE.

CROSSTABS  /TABLES=Donated BY defPresent
  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ   /CELLS=COLUMN   /COUNT ROUND CELL.

T-TEST GROUPS=defPresent(0 1)  /MISSING=ANALYSIS
  /VARIABLES=Donation CondDonation  /CRITERIA=CI(.95).

USE ALL.
COMPUTE filter_$=(default eq 0 | default eq 15).
FILTER BY filter_$.
EXECUTE.

CROSSTABS  /TABLES=Donated BY defPresent
  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ   /CELLS=COLUMN   /COUNT ROUND CELL.

T-TEST GROUPS=defPresent(0 1)  /MISSING=ANALYSIS
  /VARIABLES=Donation CondDonation  /CRITERIA=CI(.95).

USE ALL.
COMPUTE filter_$=(default eq 0 | default eq 19).
FILTER BY filter_$.
EXECUTE.

CROSSTABS  /TABLES=Donated BY defPresent
  /FORMAT=AVALUE TABLES  /STATISTICS=CHISQ   /CELLS=COLUMN   /COUNT ROUND CELL.

T-TEST GROUPS=defPresent(0 1)  /MISSING=ANALYSIS
  /VARIABLES=Donation CondDonation  /CRITERIA=CI(.95).


*Table B3.
USE ALL.
COMPUTE filter_$=(default gt 0 ).
FILTER BY filter_$.
EXECUTE.

CORRELATIONS
  /VARIABLES=Default Donation Donated CondDonation  /PRINT=TWOTAIL NOSIG  /MISSING=PAIRWISE.


USE ALL.
EXECUTE.
SPLIT FILE OFF.





